==> crud-d-1.4.0.tgz: package/index.js <==
'use strict';
var fse = require('fs-extra');
var jgeXml = require('jgeXml');
var request = require('request');
var parseString = require('xml2js').parseString;
var fs=require('fs');
var o=require('odata');
var rf=require('read-file');
var c = require('edmx-reader');
const convert = require('edmx-reader').convert;
//var ejs = require('ejs'),
 //   people = ['geddy', 'neil', 'alex'];
var  content='<%= people.join(", "); %>' ;
exports.generateSchema = function(url,project_root) {
            console.log("getting schema of resource: ");

            console.log(url.toString());

	    var file_a=project_root+"/schema.xml";

	    fse.ensureFile(file_a, err => {console.log(err) ;


		//fse.outputFile(file_a, schema, err => {
		//	console.log(err) // => null
		//  })


		request(url).pipe(fs.createWriteStream(file_a));




		//копирует 
		var xmlReader = require('read-xml');
		 
		
		 
		// pass a buffer or a path to a xml file
		xmlReader.readXML(fs.readFileSync('schema.xml'), function(err, data) {
		  if (err) {
		    console.error(err);
		  }

			   )
var xml='<shiporder orderid="889923" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"xsi:noNamespaceSchemaLocation="shiporder.xsd"><orderperson>John Smith</orderperson> <shipto> <name>Ola Nordmann</name> <address>Langgt 23</address> <city>4000 Stavanger</city> <country>Norway</country></shipto><item><title>Hide your heart</title> <quantity>1</quantity> <price>9.90</price></item></shiporder>'
var obj = jgeXml.parse(xml,function(state,token){
console.log(token);
});
//console.log();
//console.log(JSON.stringify(obj,null,2));
			  
		 // console.log('xml encoding:', data.encoding);
		 // console.log('Decoded xml:', data.content);
		});





		/*
		convert(
		    fs.createReadStream('schema.xml')
		).then(schema => {
		    console.log('Schema', schema);
 		
		}).catch(console.log);
		*/



		//fse.readFile('bril.txt', 'utf8', function (err,data) {

		 // if (err) {
		 //   return console.log(err);
		 // }
		
		// })

	    });
        };

==> crud-d-1.4.3.tgz: package/index.js <==
'use strict';
var fse = require('fs-extra');
var jgeXml = require('jgexml');
var request = require('request');
var parseString = require('xml2js').parseString;
var fs=require('fs');
var o=require('odata');
var rf=require('read-file');
var c = require('edmx-reader');
const convert = require('edmx-reader').convert;
//var ejs = require('ejs'),
 //   people = ['geddy', 'neil', 'alex'];
var  content='<%= people.join(", "); %>' ;
exports.generateSchema = function(url,project_root) {
            console.log("getting schema of resource: ");

            console.log(url.toString());

	    var file_a=project_root+"/schema.xml";

	    fse.ensureFile(file_a, err => {console.log(err) ;


		//fse.outputFile(file_a, schema, err => {
		//	console.log(err) // => null
		//  })


		request(url).pipe(fs.createWriteStream(file_a));




		//копирует 
		var xmlReader = require('read-xml');
		 
		
		 
		// pass a buffer or a path to a xml file
		xmlReader.readXML(fs.readFileSync('schema.xml'), function(err, data) {
		  if (err) {
		    console.error(err);
		  }

			   
var xml='<shiporder orderid="889923" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"xsi:noNamespaceSchemaLocation="shiporder.xsd"><orderperson>John Smith</orderperson> <shipto> <name>Ola Nordmann</name> <address>Langgt 23</address> <city>4000 Stavanger</city> <country>Norway</country></shipto><item><title>Hide your heart</title> <quantity>1</quantity> <price>9.90</price></item></shiporder>'
var obj = jgeXml.parse(xml,function(state,token){
//console.log(token);
});
//console.log();
console.log(JSON.stringify(obj,null,2));
			  
		 // console.log('xml encoding:', data.encoding);
		 // console.log('Decoded xml:', data.content);
		});





		/*
		convert(
		    fs.createReadStream('schema.xml')
		).then(schema => {
		    console.log('Schema', schema);
 		
		}).catch(console.log);
		*/



		//fse.readFile('bril.txt', 'utf8', function (err,data) {

		 // if (err) {
		 //   return console.log(err);
		 // }
		
		// })

	    });
        };
